@@ -1,4 +1,4 @@
-integrand_obj <- function(x, y, lambda, d, n.ints, alpha, s.spl){
+integrand_obj <- function(x, y, lambda, d, n.ints, c.alpha, s.spl){
   # This function evaluates
   # ( s(x) - c_alpha ) * (lambda + phi(x))
   # for a vector x.
@@ -18,7 +18,7 @@ integrand_obj <- function(x, y, lambda, d, n.ints, alpha, s.spl){
   # Written by P.Kabaila in June 2008.
   # Rewritten in R by R Mainzer, March 2017
 
-  c.alpha <- stats::qnorm(1 - alpha/2)
+ # c.alpha <- stats::qnorm(1 - alpha/2)
   tmp1 <- s.spl(x) - c.alpha
   tmp2 <- lambda + stats::dnorm(x, 0, 1)
   res <- tmp1 * tmp2
